package com.ruoyi.service.impl;

import java.util.List;

import cn.hutool.core.util.ObjUtil;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.ruoyi.common.annotation.DataScope;
import com.ruoyi.common.core.domain.model.LoginUser;
import com.ruoyi.common.exception.ServiceException;
import com.ruoyi.common.utils.DateUtils;
import com.ruoyi.common.utils.SecurityUtils;
import com.ruoyi.web.request.AutomobileEnterpriseListRequest;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.mapper.AutomobileEnterpriseMapper;
import com.ruoyi.domain.AutomobileEnterprise;
import com.ruoyi.service.AutomobileEnterpriseService;
import org.springframework.transaction.annotation.Transactional;

/**
 * 车企信息Service业务层处理
 *
 * @author gxk
 * @date 2024-01-05
 */
@Service
@Transactional
public class AutomobileEnterpriseServiceImpl extends ServiceImpl<AutomobileEnterpriseMapper, AutomobileEnterprise> implements AutomobileEnterpriseService
{
    @Autowired
    private AutomobileEnterpriseMapper automobileEnterpriseMapper;

    /**
     * 查询车企信息
     *
     * @param id 车企信息主键
     * @return 车企信息
     */
    @Override
    public AutomobileEnterprise selectAutomobileEnterpriseById(Long id)
    {
        return automobileEnterpriseMapper.selectAutomobileEnterpriseById(id);
    }

    /**
     * 查询车企信息列表
     *
     * @param request 车企信息
     * @return 车企信息
     */
    @Override
    @DataScope(deptAlias = "d")
    public List<AutomobileEnterprise> selectAutomobileEnterpriseList(AutomobileEnterpriseListRequest request)
    {
        return automobileEnterpriseMapper.selectAutomobileEnterpriseList(request);
    }

    /**
     * 新增车企信息
     *
     * @param automobileEnterprise 车企信息
     * @return 结果
     */
    @Override
    public int insertAutomobileEnterprise(AutomobileEnterprise automobileEnterprise)
    {
        //获取当前用户的部门id 部门id用来实现不同部门间的数据隔离
        LoginUser user = SecurityUtils.getLoginUser();
        Long deptId = user.getDeptId();

        // 判断企业名称是否重复
        if (lambdaQuery()
                .eq(AutomobileEnterprise::getEnterpriseName, automobileEnterprise.getEnterpriseName())
                .ne(ObjUtil.isNotEmpty(automobileEnterprise.getId()), AutomobileEnterprise::getId, automobileEnterprise.getId())
                .exists()
        ) {
            throw new ServiceException("企业名称已存在");
        }
        automobileEnterprise.setDeptId(deptId);
        automobileEnterprise.setCreateTime(DateUtils.getNowDate());
        automobileEnterprise.setCreateBy(String.valueOf(SecurityUtils.getUserId()));
        return automobileEnterpriseMapper.insert(automobileEnterprise);
    }

    /**
     * 修改车企信息
     *
     * @param automobileEnterprise 车企信息
     * @return 结果
     */
    @Override
    public int updateAutomobileEnterprise(AutomobileEnterprise automobileEnterprise)
    {
        //获取当前用户的部门id 部门id用来实现不同部门间的数据隔离
        LoginUser user = SecurityUtils.getLoginUser();
        Long deptId = user.getDeptId();
        // 判断企业名称是否重复
        if (lambdaQuery()
                .eq(AutomobileEnterprise::getEnterpriseName, automobileEnterprise.getEnterpriseName())
                .ne(ObjUtil.isNotEmpty(automobileEnterprise.getId()), AutomobileEnterprise::getId, automobileEnterprise.getId())
                .exists()
        ) {
            throw new ServiceException("企业名称已存在");
        }
        automobileEnterprise.setDeptId(deptId);
        automobileEnterprise.setUpdateTime(DateUtils.getNowDate());
        automobileEnterprise.setUpdateBy(String.valueOf(SecurityUtils.getUserId()));
        return automobileEnterpriseMapper.updateAutomobileEnterprise(automobileEnterprise);
    }

}
